/*
 *
 * This code is sample code, provided as-is, and we make no
 * warranties as to its correctness or suitablity for
 * any purpose.
 *
 * We hope that it's useful to you.  Enjoy.
 * Copyright 2008 LearningPatterns Inc.
 */

import java.util.List;

import com.javatunes.persist.MusicItem;

import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.SessionFactory;
import org.hibernate.cfg.Configuration;

public class TestHibernate {

	public static void main(String[] args) {

		SessionFactory sf;
		Session s;

		try {
			sf = new Configuration().configure().buildSessionFactory();
			s = sf.openSession();
			s.beginTransaction();

			System.out.println("*** Session connect status: " + s.isConnected());

			System.out.println("*** Query all MusicItems Where id>10 ***");
			Query q = s.createQuery("FROM MusicItem m WHERE id>10");
			List resultList = q.list();
			for (Object curObject : resultList) {
				MusicItem cur = (MusicItem)curObject;
				System.out.println("id>10 query retrieved Num: " + cur.getNum());
			}

			System.out.println("*** Pagination - first 5 then next 5 where id>10 ***");
			q.setFirstResult(0);
			q.setMaxResults(5);
			System.out.println("--- First 5 results");
			resultList = q.list();
			for (Object curObject : resultList) {
				MusicItem cur = (MusicItem)curObject;
				System.out.println("id>10 query retrieved Num: " + cur.getNum());
			}
			q.setFirstResult(5);
			q.setMaxResults(5);
			System.out.println("--- Second 5 results");
			resultList = q.list();
			for (Object curObject : resultList) {
				MusicItem cur = (MusicItem)curObject;
				System.out.println("id>10 query retrieved Num: " + cur.getNum());
			}
			
			System.out.println("*** Named Parameters **");
			Query q2 = s.createQuery("FROM MusicItem WHERE Num=:num");
			q2.setString("num", "CD501");
			MusicItem res = (MusicItem)q2.uniqueResult();  // Happen to know this is unique
			System.out.println("Num=501 query retrieved Num: " + res.getNum());

			q2.setString("num", "CD510");
			res = (MusicItem)q2.uniqueResult();  // Happen to know this is unique
			System.out.println("Num=510 query retrieved Num: " + res.getNum());

			System.out.println("** Named Query **");
			Query q3 = s.getNamedQuery("MusicItem.equalsNum");
			q3.setString("num", "CD501");
			res = (MusicItem)q3.uniqueResult();  // Happen to know this is unique
			System.out.println("Named Query num=501 retrieved Num: " + res.getNum());

			q3.setString("num", "CD510");
			res = (MusicItem)q3.uniqueResult();  // Happen to know this is unique
			System.out.println("Named Query num=510 retrieved Num: " + res.getNum());

			
			System.out.println("*** Select artist, title for all items ***");
			Query q4 = s.createQuery("SELECT m.artist, m.title FROM MusicItem m");
		    resultList = q4.list();
		    for (Object curObject : resultList) {
		    	Object[] cur = (Object[])curObject;
		    	System.out.println("Title, artist " + cur[0] + "," + cur[1]);
		    }
			
			System.out.println("*** Count(m) for id>10 ***");
			Query q5 = s.createQuery("SELECT count(m) FROM MusicItem m WHERE id>10");
			Long count = (Long)q5.uniqueResult();
			System.out.println("Num retrieved with count(m) id>10 query = " + count);

			System.out.println("*** Artist, avergage price grouped by artist ***");
			Query q6 = s.createQuery("SELECT m.artist, avg(m.price) FROM MusicItem m GROUP BY m.artist");
		    resultList = q6.list();
		    for (Object curObject : resultList) {
		    	Object[] cur = (Object[])curObject;
		    	System.out.println("Artist, average price " + cur[0] + "," + cur[1]);
		    }

		    s.getTransaction().commit();
			s.close();

		} catch (HibernateException e) {
			e.printStackTrace();
		}
		catch (Exception ex) { ex.printStackTrace(); }
	}

}
