/*
 *
 * This code is sample code, provided as-is, and we make no
 * warranties as to its correctness or suitablity for
 * any purpose.
 *
 * We hope that it's useful to you.  Enjoy.
 * Copyright 2008 LearningPatterns Inc.
 */

import java.util.HashSet;
import java.util.List;

import com.javatunes.persist.HibernateUtil;
import com.javatunes.persist.Inventory;
import com.javatunes.persist.MusicItem;

import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.Transaction;

public class TestHibernate {

	public static void main(String[] args) {

		try {

			Long id = new Long(1); // This one has no inventory records when the db is created
			Session s = HibernateUtil.getSessionFactory().getCurrentSession();
			Transaction tx = s.beginTransaction();
			System.out.println("*** Retrieving with Session.get() ***");
			MusicItem m = (MusicItem)s.get(MusicItem.class,id); // Get object/row
			for (Object cur : m.getInventoryRecords()) {
				System.out.println(cur);
			}
			tx.commit();
			System.out.println("*** END Retrieving with Session.get() ***");
			
			// LEFT JOIN FETCH query
			s = HibernateUtil.getSessionFactory().getCurrentSession();
			tx = s.beginTransaction();
			System.out.println("*** Querying with LEFT JOIN FETCH ***");
			String query = "SELECT m FROM MusicItem m LEFT JOIN FETCH " +
            	"m.inventoryRecords WHERE m.id = :id";
			Query q = s.createQuery(query);
			q.setLong("id",new Long(1));
			List l = q.list();
			System.out.println("Size of list = " + l.size());
			HashSet hs = new HashSet(l);
			System.out.println("Size of hashSet = " + hs.size());
			m = (MusicItem)hs.iterator().next();
			for (Inventory cur : m.getInventoryRecords()) {
				System.out.println(cur);
			}
			tx.commit();
			System.out.println("*** END Querying with LEFT JOIN FETCH ***");
			
			// Optional query to get locations
			s = HibernateUtil.getSessionFactory().getCurrentSession();
			tx = s.beginTransaction();
			query = "SELECT i.location FROM MusicItem mi JOIN mi.inventoryRecords i where mi.id = :id"; 
			q = s.createQuery(query);
			q.setLong("id",new Long(1));
			System.out.println("*** Locations for MusicItem 1 ***");
			for (Object cur : q.list()) {
				System.out.println(cur);
			}
			System.out.println("*** End Locations for MusicItem 1 ***");
			
		} catch (HibernateException e) {
			e.printStackTrace();
		}
		catch (Exception ex) { ex.printStackTrace(); }
	}

}
