/*
 *
 * This code is sample code, provided as-is, and we make no
 * warranties as to its correctness or suitablity for
 * any purpose.
 *
 * We hope that it's useful to you.  Enjoy.
 * Copyright 2008 LearningPatterns Inc.
 */

import java.math.BigDecimal;

import com.javatunes.persist.HibernateUtil;
import com.javatunes.persist.Inventory;
import com.javatunes.persist.MusicItem;

import org.hibernate.Criteria;
import org.hibernate.FetchMode;
import org.hibernate.HibernateException;
import org.hibernate.Query;
import org.hibernate.Session;
import org.hibernate.Transaction;
import org.hibernate.criterion.Example;
import org.hibernate.criterion.Restrictions;

public class TestHibernate {

	public static void main(String[] args) {

		try {

			// Select all MusicItems
			Session s = HibernateUtil.getSessionFactory().getCurrentSession();
			Transaction tx = s.beginTransaction();
			System.out.println("*** Criteria query for all items ***");
			Criteria crit = s.createCriteria(MusicItem.class);
			for (Object cur : crit.list()) {
				System.out.println(cur);
			}

			// Select MusicItem with id=1
			System.out.println("*** Criteria query item for id=1***");
			crit = s.createCriteria(MusicItem.class).add(Restrictions.idEq(new Long(1) ));
			for (Object cur : crit.list()) {
				System.out.println(cur);
			}
			
			// Select MusicItem with num=CD501
			System.out.println("*** Criteria query item for num=CD501***");
			crit = s.createCriteria(MusicItem.class).add(Restrictions.eq("num", "CD501" ));
			for (Object cur : crit.list()) {
				System.out.println(cur);
			}

			// Select MusicItems with price < 13 and id>10
			System.out.println("*** Criteria and query for price < 13 and id>10 ***");
			crit = s.createCriteria(MusicItem.class)
			   .add(Restrictions.and(
					   Restrictions.lt("price", new BigDecimal("13.00")),
					   Restrictions.gt("id", new Long(10))
			   ));
			for (Object cur : crit.list()) {
				System.out.println(cur);
			}
			
			// Select MusicItems with price < 13 and id>10 using conjunction
			System.out.println("*** Criteria conjunction query for price < 13 and id>10 ***");
			crit = s.createCriteria(MusicItem.class).
			   add(Restrictions.conjunction()
					   .add(Restrictions.lt("price", new BigDecimal("13.00")))
					   .add(Restrictions.gt("id", new Long(10)))
			   );
			for (Object cur : crit.list()) {
				System.out.println(cur);
			}	

			
			// Select inventory with quantity >= 25 and item id = 1
			System.out.println("*** createAlias query on Inventory for quantity >= 25 and item.id=1 ***");
			crit = s.createCriteria(Inventory.class)
			   	.createAlias("item", "i")
			   	.add(Restrictions.ge("quantity", new Integer("25")))
			   	.add(Restrictions.eq("i.id", new Long (1))
			   );
			for (Object cur : crit.list()) {
				System.out.println(cur);
			}
			
			// Select inventory with quantity >= 25 and item id = 1
			System.out.println("*** createCriteria join on Inventory for quantity >= 25 and item.id=1 ***");
			crit = s.createCriteria(Inventory.class);
			Criteria crit2 = crit.createCriteria("item", "i");
			crit.add(Restrictions.ge("quantity", new Integer("25")));
			crit2.add(Restrictions.eq("i.id", new Long (1)) );
			for (Object cur : crit.list()) {
				System.out.println(cur);
			}
			
			// Eager join on inventory records
			System.out.println("*** Eager join on Inventory Records ***");
			crit = s.createCriteria(MusicItem.class)
				.setFetchMode("inventoryRecords", FetchMode.JOIN);
			for (Object cur : crit.list()) {
				System.out.println(((MusicItem)cur).getInventoryRecords().size());
			}
	
			System.out.println("*** Regular query on Inventory for quantity >= 25 and item.id=1 ***");
			Query q = s.createQuery("SELECT inv FROM Inventory inv JOIN inv.item i WHERE quantity>=25 AND i.id=1"  );
			for (Object cur : q.list()) {
				System.out.println(cur);
			}
			
			// Example query
			System.out.println("*** Example Query for Madonna ***");
			MusicItem mi = new MusicItem();
			mi.setArtist("Madonna");
			Example ex = Example.create(mi);
			crit = s.createCriteria(MusicItem.class).add(ex);
			for (Object cur : crit.list()) {
				MusicItem curItem = (MusicItem)cur;
				System.out.println(curItem.getArtist()+ ", " + curItem.getTitle());
			}
			
			tx.commit();
		} catch (HibernateException e) {
			e.printStackTrace();
		}
		catch (Exception ex) { ex.printStackTrace(); }
	}

}
